# YT-PU

Wrapper around yt-dlp to download audio from a public YouTube playlist

## Install
### Dependencies
- [yt-dlp](https://github.com/yt-dlp/yt-dlp)

### Install yt-pu
```bash
pip install ytpu
```
It is recommended to use a dedicated virtual environment:
```bash
pipx install ytpu
```

## Usage
```bash
ytpu URL
```

Specify an output path (recommended):
```bash
ytpu -o OUTPUT_FOLDER URL
```
